@@ -1,7 +1,9 @@
-// xdr:blipFill
+// xdr:twoCellAnchor
+use super::EditAsValues;
+use super::super::super::EnumValue;
 use super::FromMarker;
 use super::ToMarker;
-use super::super::charts::Chart;
+use super::GraphicFrame;
 use super::Shape;
 use super::ConnectionShape;
 use super::Picture;
@@ -15,21 +17,21 @@ use tempdir::TempDir;
 
 #[derive(Default, Debug)]
 pub struct TwoCellAnchor {
-    edit_as: Option<String>,
+    edit_as: EnumValue<EditAsValues>,
     from_marker: FromMarker,
     to_marker: ToMarker,
-    chart: Option<Chart>,
+    graphic_frame: Option<GraphicFrame>,
     shape: Option<Shape>,
     connection_shape: Option<ConnectionShape>,
     picture: Option<Picture>,
 }
 impl TwoCellAnchor {
-    pub fn get_edit_as(&self)-> &Option<String> {
-        &self.edit_as
+    pub fn get_edit_as(&self)-> &EditAsValues {
+        &self.edit_as.get_value()
     }
 
-    pub fn set_edit_as<S: Into<String>>(&mut self, value:S)-> &mut TwoCellAnchor {
-        self.edit_as = Some(value.into());
+    pub fn set_edit_as(&mut self, value:EditAsValues)-> &mut TwoCellAnchor {
+        self.edit_as.set_value(value);
         self
     }
 
@@ -59,16 +61,16 @@ impl TwoCellAnchor {
         self
     }
 
-    pub fn get_chart(&self)-> &Option<Chart> {
-        &self.chart
+    pub fn get_graphic_frame(&self)-> &Option<GraphicFrame> {
+        &self.graphic_frame
     }
 
-    pub fn get_chart_mut(&mut self)-> &mut Option<Chart> {
-        &mut self.chart
+    pub fn get_graphic_frame_mut(&mut self)-> &mut Option<GraphicFrame> {
+        &mut self.graphic_frame
     }
 
-    pub fn set_chart(&mut self, value:Chart)-> &mut TwoCellAnchor {
-        self.chart = Some(value);
+    pub fn set_graphic_frame(&mut self, value:GraphicFrame)-> &mut TwoCellAnchor {
+        self.graphic_frame = Some(value);
         self
     }
 
@@ -131,6 +133,16 @@ impl TwoCellAnchor {
         &mut self.to_marker.adjustment_remove_colmun(num_cols);
     }
 
+    pub(crate) fn is_support(&self) -> bool {
+        match &self.graphic_frame {
+            Some(v) => {
+                return v.get_graphic().get_graphic_data().get_chart_space().get_chart().get_plot_area().is_support();
+            },
+            None => {}
+        }
+        true
+    }
+
     pub(crate) fn set_attributes(
         &mut self,
         reader:&mut Reader<std::io::BufReader<std::fs::File>>,
@@ -139,7 +151,7 @@ impl TwoCellAnchor {
         target: &str,
     ) {
         match get_attribute(e, b"editAs") {
-            Some(v) => {self.set_edit_as(v);},
+            Some(v) => {self.edit_as.set_value_string(v);},
             None => {}
         }
 
@@ -155,24 +167,24 @@ impl TwoCellAnchor {
                             self.to_marker.set_attributes(reader, e);
                         },
                         b"xdr:graphicFrame" => {
-                            let mut chart = Chart::default();
-                            chart.set_attributes(reader, e, dir, target);
-                            self.set_chart(chart);
+                            let mut obj = GraphicFrame::default();
+                            obj.set_attributes(reader, e, dir, target);
+                            self.set_graphic_frame(obj);
                         },
                         b"xdr:sp" => {
-                            let mut shape = Shape::default();
-                            shape.set_attributes(reader, e);
-                            self.set_shape(shape);
+                            let mut obj = Shape::default();
+                            obj.set_attributes(reader, e);
+                            self.set_shape(obj);
                         },
                         b"xdr:cxnSp" => {
-                            let mut connection_shape = ConnectionShape::default();
-                            connection_shape.set_attributes(reader, e);
-                            self.set_connection_shape(connection_shape);
+                            let mut obj = ConnectionShape::default();
+                            obj.set_attributes(reader, e);
+                            self.set_connection_shape(obj);
                         }
                         b"xdr:pic" => {
-                            let mut picture = Picture::default();
-                            picture.set_attributes(reader, e, dir, target);
-                            self.set_picture(picture);
+                            let mut obj = Picture::default();
+                            obj.set_attributes(reader, e, dir, target);
+                            self.set_picture(obj);
                         }
                         _ => (),
                     }
@@ -194,11 +206,8 @@ impl TwoCellAnchor {
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>, r_id: &mut i32) {
         // xdr:twoCellAnchor
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        match &self.edit_as {
-            Some(v) => {
-                attributes.push(("editAs", v));
-            },
-            None => {}
+        if &self.edit_as.has_value() == &true {
+            attributes.push(("editAs", &self.edit_as.get_value_string()));
         }
         write_start_tag(writer, "xdr:twoCellAnchor", attributes, false);
 
@@ -209,7 +218,7 @@ impl TwoCellAnchor {
         &self.to_marker.write_to(writer);
 
         // xdr:graphicFrame
-        match &self.chart {
+        match &self.graphic_frame {
             Some(v) => {
                 v.write_to(writer, r_id);
                 *r_id += 1i32;
