@@ -14,9 +14,9 @@ use super::Style;
 use super::Styles;
 use super::AutoFilter;
 use super::Hyperlink;
-use super::Color;
+use super::NumberingFormat;
 use super::Comment;
-use super::NumberFormat;
+use super::Color;
 use std::collections::BTreeMap; 
 use std::collections::HashMap;
 use helper::coordinate::*;
@@ -118,8 +118,8 @@ impl Worksheet {
     pub fn get_value<S: Into<String>>(&self, coordinate:S)-> String {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_value_by_column_and_row(col, row)
     }
 
@@ -156,8 +156,8 @@ impl Worksheet {
     pub fn get_formatted_value<S: Into<String>>(&self, coordinate:S)-> String {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_formatted_value_by_column_and_row(col, row)
     }
 
@@ -187,12 +187,12 @@ impl Worksheet {
                         to_formatted_string(value.as_str(), nmuber_format.get_format_code())
                     },
                     None => {
-                        to_formatted_string(value.as_str(), NumberFormat::FORMAT_GENERAL)
+                        to_formatted_string(value.as_str(), NumberingFormat::FORMAT_GENERAL)
                     }
                 }
             },
             None => {
-                to_formatted_string(value.as_str(), NumberFormat::FORMAT_GENERAL)
+                to_formatted_string(value.as_str(), NumberingFormat::FORMAT_GENERAL)
             }
         };
         result
@@ -231,8 +231,8 @@ impl Worksheet {
     pub fn get_cell<S: Into<String>>(&self, coordinate:S)->Option<&Cell> {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_cell_by_column_and_row(col, row)
     }
 
@@ -266,8 +266,8 @@ impl Worksheet {
     pub fn get_cell_mut<S: Into<String>>(&mut self, coordinate:S)->&mut Cell {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_cell_by_column_and_row_mut(col, row)
     }
 
@@ -334,8 +334,8 @@ impl Worksheet {
     pub fn get_style<S: Into<String>>(&self, coordinate:S) -> Option<&Style> {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_style_by_column_and_row(col, row)
     }
 
@@ -369,8 +369,8 @@ impl Worksheet {
     pub fn get_style_mut<S: Into<String>>(&mut self, coordinate:S) -> &mut Style {
         let coordinate_upper = coordinate.into().to_uppercase();
         let split = index_from_coordinate(&coordinate_upper);
-        let col = split[0];
-        let row = split[1];
+        let col = split[0].unwrap();
+        let row = split[1].unwrap();
         self.get_style_by_column_and_row_mut(col, row)
     }
 
@@ -641,17 +641,9 @@ impl Worksheet {
             }
 
             // update chart
-            for chart in self.worksheet_drawing.get_chart_collection_mut() {
-                for data_serise in chart.get_plot_area_mut().get_plot_series_mut() {
-                    for (_, data_serise_values) in data_serise.get_plot_label_mut() {
-                        data_serise_values.get_address_mut().adjustment_insert_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
-                    for (_, data_serise_values) in data_serise.get_plot_values_mut() {
-                        data_serise_values.get_address_mut().adjustment_insert_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
-                    for (_, data_serise_values) in data_serise.get_plot_category_mut() {
-                        data_serise_values.get_address_mut().adjustment_insert_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
+            for graphic_frame in self.worksheet_drawing.get_graphic_frame_collection_mut() {
+                for formula in  graphic_frame.get_graphic_mut().get_graphic_data_mut().get_chart_space_mut().get_chart_mut().get_formula_mut() {
+                    formula.get_address_mut().adjustment_insert_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
                 }
             }
         }
@@ -750,17 +742,9 @@ impl Worksheet {
             }
 
             // update chart
-            for chart in self.worksheet_drawing.get_chart_collection_mut() {
-                for data_serise in chart.get_plot_area_mut().get_plot_series_mut() {
-                    for (_, data_serise_values) in data_serise.get_plot_label_mut() {
-                        data_serise_values.get_address_mut().adjustment_remove_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
-                    for (_, data_serise_values) in data_serise.get_plot_values_mut() {
-                        data_serise_values.get_address_mut().adjustment_remove_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
-                    for (_, data_serise_values) in data_serise.get_plot_category_mut() {
-                        data_serise_values.get_address_mut().adjustment_remove_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
-                    }
+            for graphic_frame in self.worksheet_drawing.get_graphic_frame_collection_mut() {
+                for formula in graphic_frame.get_graphic_mut().get_graphic_data_mut().get_chart_space_mut().get_chart_mut().get_formula_mut() {
+                    formula.get_address_mut().adjustment_remove_coordinate(sheet_name, root_col_num, offset_col_num, root_row_num, offset_row_num);
                 }
             }
         }
@@ -819,9 +803,11 @@ impl Worksheet {
             None => false
         }
     }
+    
     pub fn get_tab_color(&self) -> &Option<Color> {
         &self.tab_color
     }
+
     pub(crate) fn get_tab_color_mut(&mut self) -> &mut Color {
         match &self.tab_color {
             Some(_) => return self.tab_color.as_mut().unwrap(),
@@ -830,9 +816,11 @@ impl Worksheet {
         self.set_tab_color(Color::default());
         self.tab_color.as_mut().unwrap()
     }
+
     pub(crate) fn set_tab_color(&mut self, value:Color) {
         self.tab_color = Some(value);
     }
+
     pub fn calculate_worksheet_dimension(&self) -> String {
         let highest = &self.cell_collection.get_highest_row_and_column();
         if highest["row"] == &0 {
